@@ -608,7 +608,7 @@ class AnalogOut(DwfDevice_SubAPI):
             raise self.dwf.exception()
         trigger_source_info_bitset = c_trigger_source_info_bitset.value
         trigger_source_info_list = [trigger_source for trigger_source in DwfTriggerSource
-                               if trigger_source_info_bitset & (1 << trigger_source.value)]
+                                    if trigger_source_info_bitset & (1 << trigger_source.value)]
         return trigger_source_info_list
 
     def enableSet(self, channel_index: int, enable: bool) -> None:
@@ -847,14 +847,14 @@ class AnalogOut(DwfDevice_SubAPI):
 
         This function is OBSOLETE. Use `nodeDataInfo` instead.
         """
-        c_nsamples_min = typespec_ctypes.c_int()
-        c_nsamples_max = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogOutDataInfo(self.hdwf, channel_index, c_nsamples_min, c_nsamples_max)
+        c_num_samples_min = typespec_ctypes.c_int()
+        c_num_samples_max = typespec_ctypes.c_int()
+        result = self.lib.FDwfAnalogOutDataInfo(self.hdwf, channel_index, c_num_samples_min, c_num_samples_max)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        nsamples_min = c_nsamples_min.value
-        nsamples_max = c_nsamples_max.value
-        return (nsamples_min, nsamples_max)
+        num_samples_min = c_num_samples_min.value
+        num_samples_max = c_num_samples_max.value
+        return (num_samples_min, num_samples_max)
 
     def dataSet(self, channel_index: int, data: np.ndarray) -> None:
         """Set data.
