@@ -22,17 +22,17 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
     """
 
     def enumerateDevices(self, enum_filter: Optional[DwfEnumFilter] = None) -> int:
-        """Build an internal list of detected devices and return the count of detected devices.
+        """Build an internal list of available Digilent Waveforms devices and return the count of devices found.
 
-        This function must be called before using other |DeviceEnumeration| methods because they obtain information
-        about enumerated devices from this internal device list.
+        This function must be called before using other |DeviceEnumeration| methods described below, because they
+        obtain information about the enumerated devices from the internal device list built by this method.
 
         Note:
             This method can take several seconds to complete.
 
         Parameters:
             enum_filter (Optional[DwfEnumFilter]): Specify which devices to enumerate.
-                If not specified, enumerate all devices.
+                If None, enumerate all devices.
 
         Returns:
             int: The number of devices detected.
@@ -61,11 +61,11 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
-            Tuple[int, int]: A tuple of the |DwfDeviceID:link| and |DwfDeviceVersion:link| integer values
-                of the selected device.
+            Tuple[int, int]: A tuple of the |DwfDeviceID:link| and |DwfDeviceVersion:link| integer
+            values of the selected device.
 
         Raises:
             DwfLibraryError: The device type and version cannot be retrieved.
@@ -86,7 +86,7 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             bool: True if the device is already opened, False otherwise.
@@ -106,7 +106,7 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             str: The user name of the device, which is a short name indicating the device type
@@ -127,7 +127,7 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             str: The device name of the device, which is a long name denoting the device type
@@ -148,7 +148,7 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             str: The 12 hex-digit unique serial number of the device.
@@ -172,14 +172,14 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
         return serial
 
     def enumerateConfigurations(self, device_index: int) -> int:
-        """Build an internal list of detected configurations for the selected device.
+        """Build an internal list of detected configurations for the specified device.
 
-        This function must be called before using the |DwfLibrary.deviceEnum.configInfo:link| method because it
-        obtains information from the internal device configuration list.
+        This function must be called before using the :py:meth:`configInfo` method described below,
+        because that method obtains information from the internal device configuration list built by this method.
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             int: The count of configurations of the device.
@@ -195,7 +195,7 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
         return config_count
 
     def _configInfoString(self, config_index: int, info: DwfEnumConfigInfo, max_size: int) -> str:
-        """Return config info, as string."""
+        """Return configuration info, as string."""
 
         c_configuration_parameter_value = ctypes.create_string_buffer(max_size)
         result = self.lib.FDwfEnumConfigInfo(
@@ -211,7 +211,7 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
         Parameters:
             config_index (int): Zero-based index of the previously enumerated configuration
-                (see the |DwfLibrary.deviceEnum.enumerateConfigurations:link| method).
+                (see the :py:meth:`enumerateConfigurations` method described above).
 
             info (DwfEnumConfigInfo): Selects which configuration parameter to retrieve.
 
@@ -243,13 +243,13 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
             Use either of the following instead:
 
-            * |DwfLibrary.deviceEnum.configInfo:link| to obtain the |DwfEnumConfigInfo.AnalogInChannelCount:link|
+            * method :py:meth:`configInfo` to obtain the |DwfEnumConfigInfo.AnalogInChannelCount:link|
               configuration value;
             * |DwfDevice.analogIn.channelCount:link|
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             int: The number of analog input channels of the device.
@@ -272,13 +272,13 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
             Use either of the following instead:
 
-            * |DwfLibrary.deviceEnum.configInfo:link| to obtain the |DwfEnumConfigInfo.AnalogInBufferSize:link|
+            * method :py:meth:`configInfo` to obtain the |DwfEnumConfigInfo.AnalogInBufferSize:link|
               configuration value;
             * |DwfDevice.analogIn.bufferSizeGet:link|
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             int: The analog input buffer size of the selected device.
@@ -303,7 +303,7 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             int: The analog input bit resolution of the selected device.
@@ -328,7 +328,7 @@ class DeviceEnumeration(DwfLibrary_SubAPI):
 
         Parameters:
             device_index (int): Zero-based index of the previously enumerated device
-                (see the |DwfLibrary.deviceEnum.enumerateDevices:link| method).
+                (see the :py:meth:`enumerateDevices` method).
 
         Returns:
             float: The analog input sample frequency of the selected device, in samples per second.
